<?php

namespace Drupal\mmenu\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Class MmenuSettingsForm to include settings for mmenu.
 *
 * @package Drupal\mmenu\Form
 *
 * @ingroup mmenu
 */
class MmenuSettingsForm extends FormBase {

  use StringTranslationTrait;

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'mmenu_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $mmenu_name = '') {

    \Drupal::messenger()->addWarning('Caution: most of settings here are currently disabled. See README');

    $mmenu = mmenu_list($mmenu_name);

    $form['general'] = [
      '#tree' => TRUE,
      '#type' => 'details',
      '#title' => $this->t('General'),
      '#weight' => -5,
      '#open' => TRUE,
    ];

    $form['general']['enabled'] = [
      '#title' => $this->t('Enabled?'),
      '#type' => 'select',
      '#options' => [
        1 => $this->t('Yes'),
        0 => $this->t('No'),
      ],
      '#default_value' => $mmenu['enabled'] ? 1 : 0,
      '#required' => TRUE,
      '#weight' => -3,
      '#description' => $this->t('Enable or disable the mmenu.'),
    ];

    $form['general']['name'] = [
      '#type' => 'hidden',
      '#value' => $mmenu_name,
    ];

    $form['actions'] = ['#type' => 'actions'];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#weight' => 0,
    ];

    $form['actions']['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#weight' => 1,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    switch ($values['op']->__toString()) {
      case t('Save'):

        $config = \Drupal::configFactory()->getEditable('mmenu.settings');
        $config->set('mmenu_item_' . $values['general']['name'], $mmenu);
        $config->save();

        // Clears mmenus cache.
        \Drupal::cache()->delete('mmenus:cache');

        \Drupal::messenger()->addWarning('The settings have been saved.');
        break;

      case t('Reset'):
        // Deletes the mmenu settings from database.
        $config = \Drupal::configFactory()->getEditable('mmenu.settings');
        $config->delete('mmenu_item_' . $values['general']['name']);

        // Clears mmenus cache.
        \Drupal::cache()->delete('mmenus:cache');

        \Drupal::messenger()->addWarning('The settings have been reset.');

        break;
    }
  }

}
